/********************************************************
 *  cd_io_c -- Common structures and classes for	*
 *  doing I/O to a cd.					*
 ********************************************************/
#ifndef __CD_IO_C_H__
#define __CD_IO_C_H__

#include <string>

#include "io_c.h"
#include "backup_info.h"

// The label that goes on the CD
const char *const CD_LABEL = "Better Backup CD Label 1.0";

const std::string CD_LABEL_SERIAL("SERIAL");	// Backup Serial # keyword
const std::string CD_LABEL_DATE("DATE");	// Backup date keyword
const std::string CD_LABEL_CD("CD");		// CD # keyword
const std::string CD_LABEL_LAST("LAST");	// Last cd of backup?
/********************************************************
 * cd_label -- The label for the CD 			*
 ********************************************************/
class cd_label {
    public:
	int serial;			// Serial number of the backup
	std::string date;		// Date the backup started
	int cd_number;			// CD Number
	bool last;			// True if this is the last of the batch
    public:
	cd_label(void):
	    serial(-1),
	    date(""),
	    cd_number(-1),
	    last(false)
	{}

	explicit cd_label(
	   const int i_cd_number,	// The number of the CD
	   const bool i_last		// Is this the last CD
	):cd_number(i_cd_number),
	  last(i_last)
        {
	    serial = backup_serial();
	    date = backup_date();
	}
	  // Destructor defaults
    private:
	  // No copy constructor
	  cd_label(const cd_label&);
	  // No assignment operator 
	  cd_label& operator = (const cd_label&);
    public:
	  void read_label(const std::string& label_file);
	  friend std::ostream& operator << (
		  std::ofstream& label_file, 
		  const cd_label &the_label);
};
/********************************************************
 * cd_io_c -- Common data for the CD/IO data		*
 ********************************************************/
class cd_io_c {
    protected:
	std::string mount_dir;		// Directory on which we mount the CD
	std::string mount_dev;		// Device to use for a mount
	std::string mount_cmd;		// Command to use to do a mount

    public:
	cd_io_c(const std::string& name,
	    const config& config);
	virtual ~cd_io_c() {};

    private:
	cd_io_c(const cd_io_c&);	// No copy constructor
	cd_io_c& operator = (const cd_io_c&);//No assignment operator
    public:
	void umount(void);
	void mount(const int cd_number);
	bool is_mounted(void);
};

#endif /* __CD_IO_C_H__ */
