/********************************************************
 * colon_line -- We read a lot of lines of the form	*
 *							*
 * 	KEYWORD: value					*
 *							*
 * This module contains a parser for such files.	*
 ********************************************************/
#ifndef __COLON_H__
#define __COLON_H__

#include <string>
#include <iostream>

#include "exception.h"
/********************************************************
 * colon_line -- Decode a line of the form		*
 * 	keyword: value					*
 ********************************************************/
class colon_line {
    private: 
	std::string line;	// The input line
	std::istream &in_file;	// Input file

	std::string keyword;	// Keyword (returned)
	std::string value;	// Value (returned)
    public:
	colon_line(std::istream& i_in_file): 
	    line(""),
	    in_file(i_in_file),
	    keyword(""),
	    value("")
	{}
	// Destructor defaults
    private:
	colon_line(colon_line&);	// No copy constructor
	colon_line& operator = (colon_line&);	// No assignment operator
    public:
	// Get the next line and decode it
	void get_line(const std::string& error_msg);

	// Get the next line and decode it based
	// throw an exception if the expected keyword
	// does not appear.
	void expect_line(
		const std::string expect_key,
		const std::string& error_msg,
		const char* const file,
		const int line);

	// Return the keyword on the line
	std::string get_keyword() 
	{
	    return (keyword);
	}
	// Return the value of the line
	std::string get_value()
	{
	    return (value);
	}
	// Return the value as an integer
	// Throw an exception if it is not
	int get_int_value(const std::string& error_msg) {
	    // Index of the current character
	    std::string::size_type cur_ch;

	    // Loop through the data and check to see if 
	    // it's all digits
	    for (cur_ch = 0; cur_ch < value.length(); ++cur_ch) {
		if (! isdigit(value[cur_ch])) 
		    INTERNAL_ERROR(error_msg);
	    }
	    return (atol(value.c_str()));
	}
};

#endif /* __COLON_H__ */
