/********************************************************
 * filer -- Class to handle lists of files and the 	*
 * 	information about them.				*
 *********************************************************/
#ifndef __FILER_H__
#define __FILER_H__
#include <sys/stat.h>
#include <map>

#include "types.h"

/********************************************************
 * The job of this class is to collect a list of files	*
 * (from an inputlist) and then provide them to the	*
 * batchers.						*
 ********************************************************/
class filer {
    private:
	// The unique id for a file
	// Used to find all the links to a file
	class id {
	    public:
		dev_t st_dev;	// Device number for this device
		ino_t st_ino;	// Inode type

		explicit id(const struct stat64 &stat):
		    st_dev(stat.st_dev),
		    st_ino(stat.st_ino) {}

		bool operator < (const id& other) const {
		    if (st_dev != other.st_dev)
			return (st_dev < other.st_dev);
		    return (st_ino < other.st_ino);
		}
	};

	// Given file name, return stat
	typedef std::map<std::string, struct stat64> file_to_stat;

	typedef std::map<id, string_set> id_to_files;

	// Map a file name to the stat info for the file
	file_to_stat file_list;

	// Map ID to all to all the files that match it
	id_to_files id_list;
    public:
	// Constructor defaults
	// Copy Constructor defaults
	// Destructor defaults
	// Assignment operator defaults
    public:
	// Add the files to the list
	void add_files(const string_set& files);

	// Return all the names for a given file
	const string_set all_names(
		const std::string& cur_file
	) const;

	// Mark these files as done
	void mark(const string_set& files);

	// Mark these files as done
	void mark(const std::string& file);
	
	// Get the stat information for a file
	const struct stat64& stat_info(const char* const file) const;

	// Get the files currently active in the filer
	const string_set get_files(void);

	const bool done(const std::string &file);
    private:
	bool non_empty_dir(
	   std::string& dir_name,	// Name of the directory to check
	   struct stat64& stat		// File mode
	);
};
#endif /* __FILER_H__ */
