/********************************************************
 * io_b -- Handle I/O for backup.			*
 * 	Since 99% of this is handled by the device	*
 * 	handlers, this is rather small.			*
 ********************************************************/
#include <cstring>
#include <unistd.h>
#include <fcntl.h>

#include "magic.h"
#include "io_b.h"
#include "config.h"
#include "tape_io_b.h"
#include "cd_io_b.h"

/********************************************************
 * new_IO -- Create a new I/O object.  Which one 	*
 * depends on the type name in the configuration	*
 ********************************************************/
io_b* const new_io_b(
    const std::string& name, 	// Name of the object
    const config& config	// Configuration information on the object
)
{
    // The type of the object
    std::string type_name = config.get_option(SECTION_IO, name, IO_TYPE);

    if (strcasecmp(type_name.c_str(), IO_TYPE_TAPE) == 0) {
	return (new tape_io_b(name, config));
    }
    if (strcasecmp(type_name.c_str(), IO_TYPE_CD) == 0) {
	return (new cd_io_b(name, config));
    }
    USER_ERROR("Invalid type name " + type_name + " for I/O module");
}

/********************************************************
 * fill_in_head -- Fill in the items in the head	*
 * 	that we need to do in this I/O			*
 ********************************************************/
void fill_in_head(
	const std::string& file_name,
	const io_info_c* const io_info
)
{
    struct file_head head;	// header of the file

    int in_fd = open(file_name.c_str(), O_RDWR);
    if (in_fd < 0)
	SYSTEM_ERROR("Could not open " + file_name);

    if (read(in_fd, &head, sizeof(head)) != sizeof(head)) 
	SYSTEM_ERROR("Could not read heading from " + file_name);

    head.file_sequence = io_info->file_sequence;
    head.media_sequence = io_info->media_sequence;

    if (lseek(in_fd, 0L, SEEK_SET) != 0L)
	SYSTEM_ERROR("Could not seek on " + file_name);

    if (write(in_fd, &head, sizeof(head)) != sizeof(head)) 
	SYSTEM_ERROR("Could not write heading of " + file_name);

    close(in_fd);
}
