/********************************************************
 * Module handle the generic backup I/O			*
 ********************************************************/
#ifndef __IO_B_H__
#define __IO_B_H__

#include "magic.h"
#include "io_c.h"
#include "config.h"
#include "batch_b.h"

/********************************************************
 * Information on a generic Backup I/O			*
 ********************************************************/
class io_b {
    public:
	io_b() {}
	virtual ~io_b() {};

    private:
	io_b(const io_b &);	// No copy constructor
	io_b & operator = (const io_b &);//No assignment operator
    public:
	virtual void write(const batch_info_b* const info) = 0;
	virtual void finish(const std::string meta_file, 
		const std::string meta_report) = 0;
	/* By default, we return 0 -- no restriction */
	/* If a derived class (i.e. tape) has a restriction
	 * it is put in there 
	 */
	virtual unsigned int block_restriction() { 
	    return (0);
	}
};

// Create a new I/O
extern io_b* const new_io_b(const std::string& name, const config& config);

/********************************************************
 * io_info_b -- Information about the batch 		*
 * 	(for the meta data record)			*
 * 	and the function to back it up.			*
 ********************************************************/
class io_info_b: public io_info_c {
    public:
	io_info_b(const char* i_type,
		  const unsigned int i_media_sequence,
		  const unsigned int i_file_sequence
	): io_info_c(i_type, i_media_sequence, i_file_sequence)
	{}
	virtual ~io_info_b() {}
	// Copy Constructor defaults
	// Assignment operator defaults
    public:
	virtual void write(std::ostream& out_file) const {
	    write_base(out_file);
	}
	void write_base(std::ostream& out_file) const {
	    out_file << META_IO_INFO << std::endl;
	    out_file << META_IO_TYPE << ": " << type << std::endl;
	    out_file << META_IO_MEDIA_SEQ << ": " << media_sequence << std::endl;
	    out_file << META_IO_FILE_SEQ << ": " << file_sequence << std::endl;
	}
};

extern void fill_in_head(
	const std::string& file_name,
	const io_info_c* const io_info
);

#endif /* __IO_B_H__ */

