/********************************************************
 * io_r -- I/O functions for restoring			*
 ********************************************************/
#ifndef __IO_R_H__
#define __IO_R_H__

#include "config.h"
#include "io_c.h"
/********************************************************
 * io_info_r -- Information about an I/O module		*
 * and the functions to handle it's restoration.	*
 ********************************************************/
class io_info_r: public io_info_c {
    public:
	io_info_r(const char* i_type,
		  const unsigned int i_media_sequence,
		  const unsigned int i_file_sequence
	): io_info_c(i_type, i_media_sequence, i_file_sequence)
	{}
	virtual ~io_info_r() {}
	// Copy Constructor defaults
	// Assignment operator defaults
};

class meta_r;
/********************************************************
 * io_r -- Class to do the I/O during a restore		*
 ********************************************************/
class io_r {
    public:
	io_r() {}
	virtual ~io_r() {};

    private:
	io_r(const io_r &);	// No copy constructor
	io_r& operator = (const io_r &);//No assignment operator
    public:
	// Read the meta file
	virtual std::string get_meta(void) = 0;	

	// Read a file from the media and put where we can get at it
	virtual std::string get_file(const io_info_r* info) = 0;

	// Remove a file after we've used it
	virtual void rm_file(const std::string& file) = 0;

	// Get the current media number
	virtual int get_cur_media(void) = 0;
};

// Create a new I/O
extern io_r* const new_io_r(const std::string& name, const config& config);

// Read the IO information from a file
extern io_info_r* const read_io(std::istream& in_file);

// Validate the contents of a file
extern void validate_file(const std::string &tmp_file,
	const io_info_c* const io_info);
#endif /* __IO_R_H__ */

