/********************************************************
 * All common magic strings used to identify		*
 * special fields in configuration files, meta data	*
 * tape labels, and so forth.				*
 ********************************************************/
#ifndef __MAGIC_H__
#define __MAGIC_H__
#include <string>
/********************************************************
 * magic strings used in meta files and other places	*
 ********************************************************/

/********************************************************
 * File and record identification strings		*
 ********************************************************/
const char* const HEADER_MAGIC("Better Backup META FILE V1.0");
const char* const FILE_RECORD("FILE_RECORD");

/********************************************************
 * Section names					*
 ********************************************************/
const char SECTION_BATCH[] = "Batch";    	// Batch (how to create a batch)
const char SECTION_IO[] = "IO";	     		// IO section (how to write backup)
const char SECTION_OPTIONS[] = "Options";	// Options section
const char SECTION_BACKUP[] = "Backup";  	// Backup description
const char SECTION_INPUT_LIST[] = "InputList";	// Input section
const char SECTION_JOB_LIST[] = "JobList";	// List of input
/********************************************************
 * Batch types						*
 ********************************************************/
// Type indicator
const char* const BATCH_TYPE("Type");

// Collection batch
const char* const BATCH_TYPE_COLLECTION("Collection");

// Slice batch
const char* const BATCH_TYPE_SLICE("Slice");

// Do we need files
const char* const BATCH_NEED_FILES("FilesNeeded");

/********************************************************
 * IO types						*
 ********************************************************/
const char* const IO_TYPE_CD("CD");	// CD-RW
const char* const IO_TYPE_TAPE("TAPE");	// Tape drive

// The keyword for the type indicator
const char* const IO_TYPE("Type");

/********************************************************
 * IO parameters					*
 ********************************************************/
const char* const IO_CD_IMAGE("ImageCommand");	// Command to produce an image
const char* const IO_CD_BURN("BurnCommand");	// Command to burn the cd
const char* const IO_CD_PRE_IMAGE("PreImage");	// Pre-image command

const char* const IO_CD_SIZE("CDSize");		// Size of the CD

const char* const IO_CD_MOUNT_DIR("MountDir");	// Directory cd is to be mounted
const char* const IO_CD_MOUNT_DEV("MountDev");	// Device which is used for mounting
const char* const IO_CD_MOUNT_CMD("MountCmd");	// Command to mount the device

const char* const IO_TAPE_DEVICE("Device");	// Device to write
const char* const IO_TAPE_SIZE("BockSize");	// Size of a single block

// Script to use for changing tapes
const char* const IO_TAPE_CHANGE_SCRIPT("ChangeScript");

// Number of files to back off at the end of tape
const char* const IO_TAPE_SAFE_COUNT("SafeCount");

/********************************************************
 * BATCH keywords (generic)				*
 ********************************************************/
const char* const BATCH_SIZE("BatchSize");	// Size of the batch

// Command to do the backup
const char* const BATCH_CMD_BACKUP_CMD("BackupCommand");

// Command to do the restore
const char* const BATCH_CMD_RESTORE_CMD("RestoreCommand");

// Command to do the verify
const char* const BATCH_CMD_VERIFY_CMD("VerifyCommand");
/********************************************************
 * BATCH_COLLECT keywords				*
 ********************************************************/
const char* const BATCH_COLLECT_FILE_SIZE("FileSize");	// Size of the result file

/********************************************************
 * BATCH_SLICE keywords					*
 ********************************************************/
const char* const BATCH_BUFFER_SIZE("BufferSize");	// Size of the copy buffer

/********************************************************
 * JobList keyword					*
 ********************************************************/
const char* const JOB_LIST_JOB("Job");	// Job to do

/********************************************************
 * Options stuff					*
 ********************************************************/
const char* const OPTION_GLOBAL("Global");	// Global Options
const char* const OPTION_BACKUP_ROOT("BackupRoot");// Root of the backup
const char* const OPTION_TMP_DIR("TempDir");// Temp directory

/********************************************************
 * Meta file keywords					*
 * 							*
 * Keywords to identify fields in a meta file		*
 ********************************************************/

/**************** BATCH META DATA **********************/

// Backup Serial number
const char* const META_SERIAL("SERIAL");

// Backup ID
const char* const META_ID("ID");

// Begin of batchinfo record (and type information)
const char* const META_BATCH_TYPE("BATCHINFO");

// Meta file for the batch sequence number
const char* const META_BATCH_NUMBER("BATCH-NUMBER");

// Meta information on the name of the batch
const char* const META_BATCH_NAME("BATCH-NAME");

// File list follows (value in this case in # files)
const char* const META_BATCH_FILES("FILES");

// Do we use files?
const char* const META_BATCH_NAMES_NEEDED("NAMES_NEEDED");

// Sequence number in a slice batch
const char* const META_BATCH_SLICE("SLICE");

// Last flag for slice batch
const char* const META_BATCH_LAST("LAST");

// Bckup command
const char* const META_BATCH_BACKUP_CMD("BACKUP_CMD");

// Restore command
const char* const META_BATCH_RESTORE_CMD("RESTORE_CMD");

// Verify command
const char* const META_BATCH_VERIFY_CMD("VERIFY_CMD");

// Meta information for IO record
const char* const META_IO_INFO("INFO");

// Meta information for the IO type
const char* const META_IO_TYPE("TYPE");

// Media sequence number
const char* const META_IO_MEDIA_SEQ("MEDIA_SEQ");

// File sequence number
const char* const META_IO_FILE_SEQ("FILE_SEQ");

// Name of the file on CD (CD/IO only)
const char* const META_CD_FILE("CD_FILE");

// End of a meta record
const char* const META_EOR("EOR");

/********************************************************
 * meta report labels					*
 ********************************************************/
const char META_FULL[] = "FULL";	// Meta report for everything
const char META_PART[] = "PART";	// Partial meta report

#endif /* __MAGIC_H__ */

