/********************************************************
 * meta_b -- Handle the meta data for a backup		*
 ********************************************************/
#include <algorithm>

#include "magic.h"
#include "exception.h"
#include "backup_info.h"
#include "batch_b.h"
#include "backup.h"
#include "io_b.h"
#include "log.h"
#include "meta_b.h"

/********************************************************
 * add_batch -- Add a batch information record to the 	*
 * 	list of meta data we have now.			*
 ********************************************************/
void meta_b::add_batch(
    const batch_info_b* const batch_info,// Information on batch
    const io_info_b* const io_info	// Information on the I/O
)		
{
    gen_info new_info(batch_info, io_info);
    info.insert(new_info);
}

/********************************************************
 * save -- Save the meta data to a file			*
 ********************************************************/
void meta_b::save(
    const std::string& file, 	// File to save the data into
    const std::string& id	// Identification for this file
) {
    log_msg('x', "Saving meta: " + id + " file: " + file);
    std::ofstream meta_file(file.c_str());
    if (meta_file.bad()) {
	SYSTEM_ERROR("Could not open meta file: " + file);
    }
    meta_file << HEADER_MAGIC << std::endl;
    meta_file << META_SERIAL << ": " << backup_serial() << std::endl;
    meta_file << META_ID << ": " << id << std::endl;
    meta_file << META_EOR << std::endl;

    // Loop through the info information and print it
    for (info_set::const_iterator cur_meta = info.begin();
	 cur_meta != info.end();
	 ++cur_meta) {
	meta_file << FILE_RECORD << std::endl;

	cur_meta->batch_info->write(meta_file);
	cur_meta->io_info->write(meta_file);
    }
    meta_file.close();
}
