/********************************************************
 * meta_c -- Common function and data for handling	*
 * 	the meta data.					*
 ********************************************************/
#include <algorithm>

#include "meta_c.h"
#include "meta_b.h"
#include "meta_r.h"

// GCC hack to force template implementation to be generated
template class meta_c<batch_info_b, io_info_b>;
template class meta_c<batch_info_r, io_info_r>;
/********************************************************
 * create_file_data -- Turn the batch information into	*
 * 	of files and information.			*
 ********************************************************/
template <typename batch_info_type, typename io_info_type> 
void meta_c<batch_info_type, io_info_type>::create_file_data(void)
{
    if (file_data.size() != 0) {
	return;
    }
    file_data.clear();

    // Loop through each batch
    for (typename info_set::const_iterator cur_info = info.begin();
	    cur_info != info.end();
	    ++cur_info) {

	// Loop through each file in the batch
	for (string_set::const_iterator cur_file = 
		    cur_info->batch_info->files.begin();
		cur_file != cur_info->batch_info->files.end();
		++cur_file) {

	    file_data[*cur_file].insert(*cur_info);
	}
    }
}
/********************************************************
 * media_less: helper function to tell if two info	*
 * records are < each other in media order.		*
 ********************************************************/
template <typename batch_info_type, typename io_info_type> 
class media_less: 
    public std::binary_function<
	    const typename meta_c<batch_info_type, io_info_type>::gen_info&, 
	    const typename meta_c<batch_info_type, io_info_type>::gen_info&, 
	    bool> 
{
    public:
	bool operator() (
		// Items to compare
		const typename meta_c<batch_info_type, 
		    io_info_type>::gen_info& a,  
		const typename meta_c<batch_info_type, 
		    io_info_type>::gen_info& b   
	    ) {
	    if (a.io_info->media_sequence < b.io_info->media_sequence)
		return (true);
	    return (a.io_info->file_sequence < b.io_info->file_sequence);
	}
};
/********************************************************
 * report -- Write out a file name			*
 ********************************************************/
template <typename batch_info_type, typename io_info_type> 
void meta_c<batch_info_type, io_info_type>::report(
    const std::string& file_name	// File name to write the report to
) {
    // The file to write the report to
    std::ofstream meta_file(file_name.c_str());

    create_file_data();

    meta_file << "==== File Section" << std::endl;

    std::string last_file = "";	// Last file displayed

    // Loop through each file
    for (typename file_data_type::const_iterator cur_file = file_data.begin();
	  cur_file != file_data.end();
	  ++cur_file) {

	meta_file << cur_file->first << std::endl;

	// Loop through each info record and print it
	for (typename info_set::const_iterator cur_info = cur_file->second.begin();
		cur_info != cur_file->second.end();
		++cur_info) {
	    meta_file << '\t' << cur_info->batch_info->type <<  " " <<
		cur_info->io_info->type << " " <<
		cur_info->io_info->media_sequence << ":" << 
		cur_info->io_info->file_sequence << 
		" Batch Number: " << 
		cur_info->batch_info->batch_number << std::endl;
	}
    }

    meta_file << "==== Batch Section" << std::endl;

    // Go through the info list and print the information
    for (typename info_set::const_iterator cur_meta = info.begin();
	 cur_meta != info.end();
	 ++cur_meta) {

	// Loop through each batch file
	meta_file << cur_meta->io_info->media_sequence << ':' << 
	    cur_meta->io_info->file_sequence <<  " " <<
	    cur_meta->batch_info->type << 
	    " Batch Number " << 
	    cur_meta->batch_info->batch_number << 
	    " Batch name " << cur_meta->batch_info->name << std::endl;

	// Loop through each file in the information
	for(string_set::const_iterator cur_file = 
			cur_meta->batch_info->files.begin();
		cur_file != cur_meta->batch_info->files.end();
		++cur_file) {
	    meta_file << '\t' << (*cur_file) << std::endl;
	}
    }
}
