/********************************************************
 * module to handle the meta data for a restore		*
 ********************************************************/
#ifndef __META_R_H__
#define __META_R_H__

#include "types.h"
#include "io_r.h"
#include "meta_c.h"
#include "batch_info_r.h"

// Indicator that a file or media record was not found
const int NOT_FOUND = 0x7FFFFFF;	

/********************************************************
 * meta_r -- Meta information for a restore		*
 ********************************************************/
class meta_r: public meta_c<batch_info_r, io_info_r> {
    public:
	// Constructor defaults
	// Destructor defaults
    public:
	std::string id;	// The id of the meta data
    public:
	// Read in a meta file and save the data
	void restore(const std::string& file_name);

	// Write a toc report
	void toc(std::ostream& out_file);

	// Find all files 
	string_set all_files(void);

	// Find all files that match these
	string_set match(const string_set& files);

    public: /* Functions to support getting restore info */
	static info_set meta_r::find_next_batch(
	    const unsigned int requested_media,	// Media number requested
	    info_set& info		// Information to search
	);
    public:
	info_set get_batch_set(
	   const string_set& files
	);

	void add_ids(std::set<int> ids, info_set& restore_set);
};

#endif /* __META_R_H__ */
