/********************************************************
 * slice_batch_r -- Module for restoring sliced files	*
 ********************************************************/
#ifndef __SLICE_BATCH_R_H__
#define __SLICE_BATCH_R_H__

#include <cstdio>
#include "batch_r.h"

/********************************************************
 * slice_batch_r -- Information about a slice batch	*
 * and the function to restore this information.	*
 ********************************************************/
class slice_batch_info_r: public batch_info_r {
    private:
	unsigned int sequence;	// Sequence number of this slice file
	bool last;		// Is this the last one?
    public:
	slice_batch_info_r(
	    const batch_info_r& info,
	    std::istream& in_file
	);
	~slice_batch_info_r() {};
    private:
	// No copy constructor
	slice_batch_info_r(const slice_batch_info_r&); 

	// No assignment operator
	slice_batch_info_r& operator = (const slice_batch_info_r&);	

    friend class slice_batch_r;
};
/********************************************************
 * slice_batch_r -- Handle the batching for a 		*
 * slice restore.					*
 ********************************************************/
class slice_batch_r: public batch_r {
    private:
	FILE *pipe_file;	// The pipe to the tar command
	std::string name_file;	// File containing names to restore
    public:
	// Constructor defaults
	// Destructor defaults
	// Copy Constructor defaults
	// Assignment operator defaults
    public:
	// Verify a batch
	void verify(
	    const meta_r::info_set& info,
	    io_r* const io 
	);
	// Restore a batch
	void restore(
	     const meta_r::info_set& set,
	     io_r* const io,
	     const string_set& files
	);
    private:
	void verify_restore(
	    const meta_r::info_set& info,// Information about the batch
	    std::string& cmd,		 // Command to use for restore/verify
            io_r* const io 	         // The I/O to use for the verify
	);
};

#endif /* __SLICE_BATCH_R_H__ */


