/********************************************************
 * tape_io_c -- Stuff to do a tape I/O backup or restore*
 ********************************************************/
#include <stdint.h>
#include <cstdlib>
#include <limits.h>
#include <unistd.h>
#include <sys/fcntl.h>

#include "magic.h"
#include "util.h"
#include "raw_tape.h"
#include "tape_file.h"
#include "tape_null.h"
#include "tape_tape.h"
#include "tape_io_c.h"

/********************************************************
 * tape_io_c -- Construct a new tape I/O object		*
 ********************************************************/
tape_io_c::tape_io_c(
    const std::string& name,	// Name of the I/O
    const config& config,	// Global config data
    const int mode		// Mode to use for opening
)
{
    device = config.get_option(SECTION_IO, name, IO_TAPE_DEVICE);

    if (config.defined(SECTION_IO, name, IO_TAPE_SIZE)) {
	block_size = convert_size(
		config.get_option(SECTION_IO, name, IO_TAPE_SIZE));
    } else {
	block_size = 20 * 512;	// Default block size is 20b
    }
    if (device == "/dev/null") {
	mt = new tape_null;
    } else if (device.substr(0, 5) == "file:") {
	mt = new tape_file(device, mode);
    } else {
	mt = new tape_tape(device, mode);
    }
    first = 1;
}
