#ifndef __TTY_LOCK_H_ 
#define __TTY_LOCK_H_ 
/********************************************************
 * This class is used to lock the tty when we are	*
 * asking the user for information.			*
 * 							*
 * Usage:						*
 * 	{						*
 * 		tty_lock var;				*
 * 		std::cout << "Prompt: ";		*
 * 		std::cin >> response;			*
 * 	}						*
 ********************************************************/

#include <sys/file.h>
#include <iostream>

#include "util.h"
#include "exception.h"
#include "log.h"

class tty_lock {
    private:
	static bool locked;	// Are we locked now?
    public:
	tty_lock(void) {
	    assert(locked == false);

	    struct flock get_lock;	// lock information for getting
	    get_lock.l_type = F_RDLCK;
	    get_lock.l_whence = 0;
	    get_lock.l_start = 0;
	    get_lock.l_len = 1;
	    get_lock.l_pid = 0;

	    if (fcntl(0, F_GETLK, &get_lock) != 0)
		SYSTEM_ERROR("Could not get lock information on <stdin>");

	    if (get_lock.l_type != F_UNLCK) {
		log_msg('x', "WARNING: <stdin> already locked");
		log_msg('x', "By " + int_to_string(get_lock.l_pid) +
			" (" + int_to_string(get_lock.l_type) + ", " +
			int_to_string(get_lock.l_start) + ", " +
			int_to_string(get_lock.l_len) + ")");
		return;
	    }

	    struct flock lock;	// Lock we are setting
	    lock.l_type = F_RDLCK;
	    lock.l_whence = 0;
	    lock.l_start = 0;
	    lock.l_len = 1;

	    if (fcntl(0, F_SETLK, &lock) != 0)
		SYSTEM_ERROR("Could not lock <stdin>");

	    locked = true;
	}
	~tty_lock(void) {

	    assert(locked == true);


	    struct flock lock;		// Clear the lock
	    lock.l_type = F_UNLCK;
	    lock.l_whence = 0;
	    lock.l_start = 0;
	    lock.l_len = 1;
	    if (fcntl(0, F_SETLK, &lock) != 0)
		SYSTEM_ERROR("Could not unlock <stdin>");

	    locked = false;
	}
    private:
	tty_lock(const tty_lock&);
	tty_lock operator = (const tty_lock&);
};
#endif /* __TTY_LOCK_H_ */

